# Changelog

## [V1.3.0](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V1.3.0) (2026-03-04)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/1.3.0...V1.3.0)



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
